@@ -2,20 +2,27 @@ class ActivationsAndGradients:
     """ Class for extracting activations and
     registering gradients from targetted intermediate layers """
 
-    def __init__(self, model, target_layer):
+    def __init__(self, model, target_layer, reshape_transform):
         self.model = model
         self.gradients = []
         self.activations = []
+        self.reshape_transform = reshape_transform
 
         target_layer.register_forward_hook(self.save_activation)
         target_layer.register_backward_hook(self.save_gradient)
 
     def save_activation(self, module, input, output):
-        self.activations.append(output)
+        activation = output
+        if self.reshape_transform is not None:
+            activation = self.reshape_transform(activation)
+        self.activations.append(activation.cpu())
 
     def save_gradient(self, module, grad_input, grad_output):
         # Gradients are computed in reverse order
-        self.gradients = [grad_output[0]] + self.gradients
+        grad = grad_output[0]
+        if self.reshape_transform is not None:
+            grad = self.reshape_transform(grad)
+        self.gradients = [grad.cpu()] + self.gradients
 
     def __call__(self, x):
         self.gradients = []
