@@ -32,7 +32,10 @@ class BaseCAM:
         raise Exception("Not Implemented")
 
     def get_loss(self, output, target_category):
-        return output[:, target_category]
+        loss = 0
+        for i in range(len(target_category)):
+            loss = loss + output[i, target_category[i]]
+        return loss
 
     def get_cam_image(self,
                       input_tensor,
@@ -41,39 +44,48 @@ class BaseCAM:
                       grads,
                       eigen_smooth=False):
         weights = self.get_cam_weights(input_tensor, target_category, activations, grads)
-
-        weighted_activations = weights[:, None, None] * activations
-
+        weighted_activations = weights[:, :, None, None] * activations
         if eigen_smooth:
             cam = get_2d_projection(weighted_activations)
         else:
-            cam = weighted_activations.sum(axis=0)
-
+            cam = weighted_activations.sum(axis=1)
         return cam
 
     def forward(self, input_tensor, target_category=None, eigen_smooth=False):
+
         if self.cuda:
             input_tensor = input_tensor.cuda()
 
         output = self.activations_and_grads(input_tensor)
 
+        if type(target_category) is int:
+            target_category = [target_category] * input_tensor.size(0)
+
         if target_category is None:
-            target_category = np.argmax(output.cpu().data.numpy())
+            target_category = np.argmax(output.cpu().data.numpy(), axis=-1)
+        else:
+            assert(len(target_category) == input_tensor.size(0))
 
         self.model.zero_grad()
         loss = self.get_loss(output, target_category)
         loss.backward(retain_graph=True)
 
-        activations = self.activations_and_grads.activations[-1].cpu().data.numpy()[0, :]
-        grads = self.activations_and_grads.gradients[-1].cpu().data.numpy()[0, :]
+        activations = self.activations_and_grads.activations[-1].cpu().data.numpy()
+        grads = self.activations_and_grads.gradients[-1].cpu().data.numpy()
+
         cam = self.get_cam_image(input_tensor, target_category, 
             activations, grads, eigen_smooth)
 
         cam = np.maximum(cam, 0)
-        cam = cv2.resize(cam, input_tensor.shape[2:][::-1])
-        cam = cam - np.min(cam)
-        cam = cam / np.max(cam)
-        return cam
+
+        result = []
+        for img in cam:
+            img = cv2.resize(img, input_tensor.shape[-2:][::-1])
+            img = img - np.min(img)
+            img = img / np.max(img)
+            result.append(img)
+        result = np.float32(result)
+        return result
 
     def forward_augmentation_smoothing(self,
                                        input_tensor,
@@ -92,13 +104,13 @@ class BaseCAM:
                 target_category, eigen_smooth)
 
             # The ttach library expects a tensor of size BxCxHxW
-            cam = cam[None, None, :, :]
+            cam = cam[:, None, :, :]
             cam = torch.from_numpy(cam)
             cam = transform.deaugment_mask(cam)
 
             # Back to numpy float32, HxW
             cam = cam.numpy()
-            cam = cam[0, 0, :, :]
+            cam = cam[:, 0, :, :]
             cams.append(cam)
 
         cam = np.mean(np.float32(cams), axis=0)
