@@ -8,7 +8,9 @@ class GradCAM(BaseCAM):
         reshape_transform=None):
         super(GradCAM, self).__init__(model, target_layer, use_cuda, reshape_transform)
 
-    def get_cam_weights(self, input_tensor, 
-                              target_category, 
-                              activations, grads):
-        return np.mean(grads, axis=(1, 2))
\ No newline at end of file
+    def get_cam_weights(self,
+                        input_tensor,
+                        target_category,
+                        activations,
+                        grads):
+        return np.mean(grads, axis=(2, 3))
\ No newline at end of file
